from phdictionary.dictionary import get_definition,\
    get_synonym,\
    get_french_english,\
    get_english_french, \
    get_synonyms_from_file, \
    get_french_english_from_file, \
    get_definition_from_file